use std::net::IpAddr;
use camino::Utf8PathBuf;
use color_eyre::eyre::WrapErr;
use color_eyre::Result;
use figment::Figment;
use figment::providers::Format;
use fstr::FStr;
use serde::{Deserialize, Serialize};
use validator::Validate;

#[derive(Debug, Serialize, Deserialize, Validate)]
pub struct Config {
    pub http_address: IpAddr,
    pub http_port: u16,
    pub api_secret: FStr<64>,
    pub database_file: Utf8PathBuf,
}

pub fn load_config() -> Result<Config> {
    let figment = Figment::new()
        .merge(figment::providers::Toml::file("config.toml"))
        .merge(figment::providers::Env::prefixed("PIMA_").only(&["HTTP_ADDRESS", "HTTP_PORT", "API_SECRET"]));

    let config = figment.extract::<Config>().wrap_err("Failed to load configuration.")?;

    config.validate().wrap_err("Failed to validate configuration.")?;

    Ok(config)
}