mod create_picture;
mod api_error;

use std::sync::Arc;
use axum::{routing, Router};
use color_eyre::Result;
use sqlx::SqlitePool;
use crate::config::Config;
use crate::http_api::create_picture::create_picture;

#[derive(Debug)]
struct ContextInner {
    pub database: SqlitePool,
    pub config: Arc<Config>,
}

type Context = Arc<ContextInner>;

pub async fn start_http_api_server(database: SqlitePool, config: Arc<Config>) -> Result<()> {
    let listener = tokio::net::TcpListener::bind((config.http_address, config.http_port)).await?;

    let router = Router::new()
        .route("/pictures/", routing::post(create_picture))
        .with_state(Arc::new(ContextInner {
            database,
            config,
        }));

    axum::serve(listener, router).await?;
    Ok(())
}