mod config;
mod http_api;

use std::sync::Arc;
use color_eyre::eyre::WrapErr;
use color_eyre::Result;
use crate::config::load_config;
use crate::http_api::start_http_api_server;

#[tokio::main]
async fn main() -> Result<()> {
    color_eyre::install().unwrap();
    env_logger::init();

    let config = Arc::new(load_config()?);

    log::debug!("Loaded configuration: {:#?}", config);

    let database = sqlx::SqlitePool::connect(&format!("sqlite://{}", config.database_file))
        .await
        .wrap_err("Failed to open the database connection.")?;

    log::info!("Initialization successful.");

    start_http_api_server(database, Arc::clone(&config)).await?;

    Ok(())
}
